# coding: utf-8

"""
    Account Service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from account-service_client.api.account_api import AccountApi


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountApi()

    def tearDown(self) -> None:
        pass

    def test_profile_get(self) -> None:
        """Test case for profile_get

        Get profile
        """
        pass

    def test_profile_put(self) -> None:
        """Test case for profile_put

        Update profile
        """
        pass

    def test_settings_get(self) -> None:
        """Test case for settings_get

        Get settings
        """
        pass


if __name__ == '__main__':
    unittest.main()
